@@ -174,6 +174,31 @@ def test_make_file_matching_md5_record_matches_does_not_return_none(
     assert mock_accession.preflight_helper.make_file_matching_md5_record.mock_calls
 
 
+def test_accession_patch_experiment_analyses(mock_accession):
+    mock_accession.new_files = [EncodeFile({"@id": "/files/foo/"})]
+    mock_accession.patch_experiment_analyses()
+    assert mock_accession.conn.patch.mock_calls[0][1][0] == {
+        "_enc_id": "foo",
+        "analyses": [{"files": ["/files/foo/"]}],
+    }
+    assert mock_accession.conn.patch.mock_calls[0][2]["extend_array_values"] is True
+
+
+def test_accession_patch_experiment_analyses_noop_when_analysis_already_exists(
+    capsys, mock_accession
+):
+    mock_accession.new_files = [EncodeFile({"@id": "/files/1/"})]
+    mock_accession.patch_experiment_analyses()
+    captured = capsys.readouterr()
+    assert captured.out.endswith(
+        (
+            "Will not patch analyses for experiment foo, found analysis ['/files/1/'] "
+            "matching the current set of accessioned files ['/files/1/']\n"
+        )
+    )
+    assert not mock_accession.conn.patch.mock_calls
+
+
 @pytest.mark.docker
 @pytest.mark.filesystem
 def test_raw_files_accessioned(mirna_accessioner):
@@ -371,17 +396,22 @@ def test_accession_init(mock_accession: Accession, lab: str, award: str) -> None
     ],
 )
 def test_accession_factory(
-    mocker, mock_gc_backend, pipeline_type, condition, accessioner_class
+    mocker, mock_gc_backend, server_name, pipeline_type, condition, accessioner_class
 ):
+    """
+    The Connection class actually tries to make connections to the server within its
+    __init__, so need to mock out.
+    """
     mocker.patch(
         "builtins.open",
         mocker.mock_open(read_data='{"workflowRoot": "gs://foo/bar", "calls": {}}'),
     )
+    mocker.patch("accession.accession.Connection")
     with condition:
         accessioner = accession_factory(
             pipeline_type,
             "metadata.json",
-            "dev",
+            server_name,
             "baz",
             "qux",
             backend=mock_gc_backend,
