@@ -7,7 +7,7 @@ from accession.task import Task
 @pytest.mark.filesystem
 def test_gcfile_init(metadata_json, normal_analysis):
     task = metadata_json["calls"]["atac.bam2ta"][0]
-    new_task = Task("bam2ta", task, normal_analysis)
+    new_task = Task("bam2ta", task)
     filekey = "ta"
     filename = new_task.outputs[filekey]
     md5sum = normal_analysis.backend.md5sum(filename)
@@ -18,3 +18,4 @@ def test_gcfile_init(metadata_json, normal_analysis):
     assert new_file.md5sum == md5sum
     assert new_file.size == size
     assert new_file.task is new_task
+    assert new_file.SCHEME == "gs://"
